using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinTree;

namespace InfragisticsError
{
    public partial class VehicleView : UserControl
    {
        #region Constructor
        public VehicleView()
        {
            InitializeComponent();
        }
        #endregion

        #region Public Methods
        public void ShowVehicleInformation()
        {
            VehicleTree.BeginUpdate();
            VehicleTree.ViewStyle = Infragistics.Win.UltraWinTree.ViewStyle.Grid;
            lblEmptyVehicleInformation.Visible = false;
            VehicleTree.BringToFront();
            VehicleTree.SetDataBinding(null, null);
            VehicleTree.SetDataBinding(GetData(), null);
            UltraTreeColumnSet columnSet = VehicleTree.Nodes.ColumnSetResolved;
            columnSet.CellAppearance.TextVAlign = VAlign.Middle;
            columnSet.ColumnSettings.AllowColMoving = Infragistics.Win.Layout.GridBagLayoutAllowMoving.None;
            columnSet.BorderStyleCell = UIElementBorderStyle.Solid;
            columnSet.CellWrapText = DefaultableBoolean.True;
            for (int iterator = 0; iterator < columnSet.Columns.Count; iterator++)
            {
                UltraTreeNodeColumn column = columnSet.Columns[iterator];
                switch (column.Key)
                {
                    case "Type":                        
                        column.LayoutInfo.MinimumCellSize = new Size(225, 30);
                        column.HeaderAppearance.FontData.Bold = DefaultableBoolean.True;
                        column.CellAppearance.BackColor = Color.FromKnownColor(KnownColor.ControlLight);
                        column.CellAppearance.FontData.Bold = DefaultableBoolean.True;
                        column.ShowSortIndicators = DefaultableBoolean.True;
                        column.AllowSorting = DefaultableBoolean.True;
                        break;
                    case "Parts":
                        column.LayoutInfo.MinimumCellSize = new Size(125, 30);
                        column.HeaderAppearance.FontData.Bold = DefaultableBoolean.True;
                        column.ShowSortIndicators = DefaultableBoolean.True;
                        column.AllowSorting = DefaultableBoolean.True;
                        break;
                    default:
                        column.ShowSortIndicators = DefaultableBoolean.False;
                        column.AllowSorting = DefaultableBoolean.False;
                        break;
                }
            }
            VehicleTree.EndUpdate();
        }        
        #endregion

        #region Private Methods
        public DataTable GetData()
        {
            DataTable table = new DataTable("Vehicle");
            table.Columns.Add("Type", typeof(System.String));
            table.Columns.Add("Parts", typeof(System.String));
            table.Columns.Add("Number of Wheels?", typeof(System.String));
            table.Rows.Add(new object[] { "Car", "Steering wheel, Engine", "4" });
            table.Rows.Add(new object[] { "Bicycle", "Handle, Pedal", "2" });
            table.Rows.Add(new object[] { "Tricycle", "Handle, Pedal", "3" });
            return table;
        }
        #endregion

        #region UI events
        private void VehicleTree_AfterCellActivate(object sender, EventArgs e)
        {
            VehicleTree.ContextMenuStrip = CntxMnuVehicleInformation;
            VehicleTree.SelectedNodes.Clear();
            VehicleTree.ActiveCell.Node.Selected = true;
            VehicleTree.ActiveCell = null;
        }

        private void VehicleTree_MouseEnterElement(object sender, UIElementEventArgs e)
        {
            if (e.Element is UltraTreeNodeCellUIElement)
            {
                UltraTreeNodeCellUIElement cellUIElement = e.Element as UltraTreeNodeCellUIElement;
                if (cellUIElement == null || cellUIElement.Cell == null || cellUIElement.Cell.Value == null || cellUIElement.Cell.Value.Equals(string.Empty))
                    return;
                TTip.SetToolTip(VehicleTree, cellUIElement.Cell.Text);
            }
        }

        private void VehicleTree_MouseLeaveElement(object sender, UIElementEventArgs e)
        {
            TTip.Hide((IWin32Window)(VehicleTree.Parent.Parent));
        }

        private void VehicleTree_KeyDown(object sender, KeyEventArgs e)
        {
        }

        private void VehicleTree_KeyUp(object sender, KeyEventArgs e)
        {
        }

        private void VehicleTree_DoubleClick(object sender, EventArgs e)
        {  
        }

        private void VehicleTree_MouseDown(object sender, MouseEventArgs e)
        {
            //This check is to handle the case where there is no data to display and only the message is displayed
            if (VehicleTree.Nodes.Count == 0)
            {
                VehicleTree.ActiveCell = null;
                VehicleTree.ActiveNode = null;
                return;
            }
            //Capture cell selection based on mouse click point
            Point mousePoint = new Point(e.X, e.Y);
            Infragistics.Win.UIElement element = ((UltraTree)sender).UIElement.ElementFromPoint(mousePoint);
            //If user clicked on a non cell area
            if (element == null) return;
            VehicleTree.BeginUpdate();
            UltraTreeNodeCell treeNodeCell = element.GetContext(typeof(UltraTreeNodeCell)) as UltraTreeNodeCell;
            //If user has clicked on a cell show context menu
            if (treeNodeCell != null) treeNodeCell.Activate();
            VehicleTree.EndUpdate();
        }
        #endregion
    }
}
